@@ -1,9 +1,9 @@
 from manga_py.provider import Provider
+from manga_py.download_methods import WholeArchiveDownloader
 from .helpers.std import Std
-from .helpers._http2 import Http2
-
 
 class MyMangaListOrg(Provider, Std):
+    _downloader = WholeArchiveDownloader
 
     def get_chapter_index(self) -> str:
         # re = self.re.compile(r'/chapter-[^/]+-(\d+)')
@@ -23,10 +23,6 @@ class MyMangaListOrg(Provider, Std):
     def get_chapters(self):
         return self._elements('.chapter_info_download a')
 
-    def loop_chapters(self):
-        http2 = Http2(self)
-        http2.download_archives(self.chapters)
-
     def get_files(self):
         return []
 
